# Providers

Providers are generic bridges to third-party components. They provide two benefits:

1. ability for plugins to override third-party components, because providers are loaded through `getComponent`
2. allows us to avoid painting ourselves into a corner with a third-party component
